@@ -1,11 +1,11 @@
-#!/usr/bin/python
+#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
 
-class style(object):
+class style:
 
-    ESC = "\x1b["
-    END = "m"
+    ESC = '\x1b['
+    END = 'm'
 
     names = {
         'BOLD': 1,
@@ -24,4 +24,4 @@ class style(object):
     }
 
     for color, num in names.items():
-        vars()[color] = '{}{}{}'.format(ESC, num, END)
+        vars()[color] = f'{ESC}{num}{END}'
